@@ -2,8 +2,9 @@
 #define _Distributions_h_
 
 #include <string>
-#include <fstream>
+
 #include <iostream>
+#include <Rmath.h>
 #include <vector>
 #include <list>
 #include <math.h>
